==> easy_net_tf-0.0.54.tar.gz: easy_net_tf-0.0.54/easy_net_tf/utility/file.py <==
import random
import os

from pathlib import Path


class UtilityFile:
    @staticmethod
    def _line_generator(file_path):
        """
        get a line generator of a file
        :param file_path:
        :return:
        """
        with file_path.open('r') as file:
            while True:
                line = file.readline()
                if line:
                    yield line
                else:
                    return

    @staticmethod
    def _line_shuffle(file_path):
        """
        first get all lines in file, then shuffle, finally save to file again.
        :param file_path:
        :return:
        """
        # read
        with file_path.open('r') as file:
            info_list = file.readlines()

        # shuffle
        random.shuffle(info_list)

        # write
        with file_path.open('w') as file:
            for info in info_list:
                file.write(info)

    @staticmethod
    def get_file_list(files_dir, shuffle):
        """

        :param files_dir:
        :param shuffle:
        :return:
        """

        file_list = os.listdir(files_dir.__str__())

        if shuffle:
            random.shuffle(file_list)

        return file_list

    @staticmethod
    def get_line_generator(file_path,
                           shuffle):
        """

        :param file_path:
        :param shuffle: True: first shuffle and save, then return generator; False: return generator
        :return:
        """

        if shuffle:
            UtilityFile._line_shuffle(file_path)

        return UtilityFile._line_generator(file_path)

    @staticmethod
    def save_str_list(file_path,
                      info_list,
                      mode='w'):
        """
        save a list of info to a file
        :param file_path: Path
        :param info_list: a list of info to save
        :param mode: file mode
        :return:
        """
        with file_path.open(mode) as file:
            for info in info_list:
                file.write(str(info))


if __name__ == '__main__':
    save_list = ['net',
                 0.88,
                 128,
                 'hello',
                 False,
                 True,
                 None]

    UtilityFile.save_str_list(Path('test.txt'), save_list)

==> easy_net_tf-0.0.72.tar.gz: easy_net_tf-0.0.72/easy_net_tf/utility/file.py <==
import random
import os


class UtilityFile:
    @staticmethod
    def _line_generator(read_path):
        """
        get a line generator of a file
        :param read_path: string
        :return:
        """
        with open(read_path, 'r') as file:
            while True:
                line = file.readline()
                if line:
                    yield line
                else:
                    return

    @staticmethod
    def _line_shuffle(read_path):
        """
        first get all lines in file, then shuffle, finally save to file again.
        :param read_path: string
        :return:
        """
        # read
        with open(read_path, 'r') as file:
            info_list = file.readlines()

        # shuffle
        random.shuffle(info_list)

        # write
        with open(read_path, 'w') as file:
            for info in info_list:
                file.write(info)

    @staticmethod
    def get_file_list(directory, shuffle):
        """

        :param directory:
        :param shuffle:
        :return:
        """

        file_list = os.listdir(directory)

        if shuffle:
            random.shuffle(file_list)

        return file_list

    @staticmethod
    def get_line_generator(read_path,
                           shuffle):
        """

        :param read_path:
        :param shuffle: True: first shuffle and save, then return generator; False: return generator
        :return:
        """

        if shuffle:
            UtilityFile._line_shuffle(read_path)

        return UtilityFile._line_generator(read_path)

    @staticmethod
    def save_str_list(write_path,
                      info_list,
                      mode='w'):
        """
        save a list of info to a file
        :param write_path: string
        :param info_list: a list of info to save
        :param mode: file mode
        :return:
        """
        with open(write_path, mode) as file:
            for info in info_list:
                file.write(str(info))


if __name__ == '__main__':
    save_list = ['net',
                 0.88,
                 128,
                 'hello',
                 False,
                 True,
                 None]

    UtilityFile.save_str_list('test.txt', save_list)
